@@ -4,7 +4,7 @@
 #include "spvm_base.h"
 
 enum {
-  SPVM_DESCRIPTOR_C_ID_INTERFACE_T,
+  SPVM_DESCRIPTOR_C_ID_CALLBACK_T,
   SPVM_DESCRIPTOR_C_ID_VALUE_T,
   SPVM_DESCRIPTOR_C_ID_POINTER_T,
   SPVM_DESCRIPTOR_C_ID_NATIVE,
